import {
  select,
  json,
  tsv,
  geoPath,
  geoNaturalEarth1,
  zoom,
  event
} from 'd3';

import { feature } from 'topojson';

const svg = select('svg');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);


const g = svg.append('g');

let countryName;
let selectedCountry;
let countries;

const onClick = selectedCountry => {
  render(selectedCountry); 
}

g.append('path')
  .attr('class', 'sphere')
  .attr('d', pathGenerator({type: 'Sphere'}));


Promise.all([
  tsv('https://unpkg.com/world-atlas@1.1.4/world/50m.tsv'),
  json('https://unpkg.com/world-atlas@1.1.4/world/50m.json')
]).then(([tsvData, topoJSONdata]) => {

  countryName = tsvData.reduce((accumulator, d) => {
    accumulator[d.iso_n3] = d.name;
    return accumulator;
  }, {});
 
  countries = feature(topoJSONdata, topoJSONdata.objects.countries);
  render(selectedCountry); 
   
});

const render = selectedCountry => {
  
  const pathSelection = g.selectAll('path').data(countries.features)
  pathSelection.enter().append('path')
    .attr('class', 'country')
    .attr('d', pathGenerator)
  .merge(pathSelection)
    .attr('fill', d=>
      countryName[d.id] === selectedCountry
        ? '#c6a84d'
        : '#3e5936')
    .on('click', d => {
      onClick(countryName[d.id]);
      
    })
  
  const textSelection = g.selectAll('text').data(countries.features);
  
  textSelection.enter().append('text')
    .attr('x',10)
    .attr('y',20)'
    .style("fill",'#204dad')
  .merge(textSelection)
    .text( d=> countryName[d.id] === selectedCountry
        ? selectedCountry
        : '')
  
}
